use std::sync::Arc;

use axum::{
    Json,
    extract::{Json as ExtractJson, State},
    response::IntoResponse,
    http::StatusCode
};
use serde::Deserialize;
use bb8::Pool;
use bb8_postgres::PostgresConnectionManager;
use tokio_postgres::NoTls;



#[derive(Deserialize)]
#[serde(rename_all = "camelCase")]
pub struct JoinRequest {
    access_token: String,
    selected_profile: String,
    server_id: String,
}

pub async fn join(
    State(pool): State<Arc<Pool<PostgresConnectionManager<NoTls>>>>,
    ExtractJson(payload): ExtractJson<JoinRequest>,
) -> impl IntoResponse {
    let conn = match pool.get().await {
        Ok(conn) => conn,
        Err(_) => return (StatusCode::INTERNAL_SERVER_ERROR, Json(serde_json::json!({
            "error": "InternalServerError",
            "errorMessage": "Failed to get DB connection"
        }))).into_response()
    };

    let query = "UPDATE accounts SET server_id = $1 WHERE uuid = $2 AND access_token = $3";
    let result = conn
        .execute(query, &[&payload.server_id, &payload.selected_profile, &payload.access_token])
        .await;

    match result {
        Ok(rows_updated) if rows_updated > 0 => {
            // Возвращаем пустую страницу с кодом 204
            (StatusCode::NO_CONTENT).into_response()
        },
        Ok(_) => (StatusCode::UNAUTHORIZED, Json(serde_json::json!({
            "error": "IllegalArgumentException",
            "errorMessage": "Bad login",
            "cause": ""
        }))).into_response(),
        Err(_) => (StatusCode::INTERNAL_SERVER_ERROR, Json(serde_json::json!({
            "error": "InternalServerError",
            "errorMessage": "Failed to update server_id"
        }))).into_response()
    }
}
